@@ -2,9 +2,8 @@ from alpacka.pipes.ncof_pipeline import ncof_pipeline
 from alpacka.pipes.tfidf_pipeline import tfidf_pipeline
 
 class Pipeline:
-    def __init__(self):
-        self.ncof = ncof_pipeline()
-        self.ncof.set_class_perspective(1)
+    def __init__(self, class_perspective = 1, num_words = None):
+        self.ncof = ncof_pipeline(num_words, class_perspective)
         self.tfidf = tfidf_pipeline()
 
 
